@@ -16,7 +16,7 @@ from golf.core.builder_auth import generate_auth_code, generate_auth_routes
 from golf.core.builder_telemetry import (
     generate_telemetry_imports,
 )
-from golf.cli.branding import create_build_header, get_status_text, STATUS_ICONS, GOLF_BLUE
+from golf.cli.branding import create_build_header, get_status_text
 from golf.core.config import Settings
 from golf.core.parser import (
     ComponentType,
@@ -383,6 +383,22 @@ class CodeGenerator:
         console.print()
         console.print(get_status_text("success", f"Build completed successfully in {output_dir_display}"))
 
+    def _generate_root_file_imports(self) -> list[str]:
+        """Generate import statements for automatically discovered root files."""
+        root_file_imports = []
+        discovered_files = discover_root_files(self.project_path)
+
+        if discovered_files:
+            root_file_imports.append("# Import root-level Python files")
+
+            for filename in sorted(discovered_files.keys()):
+                module_name = Path(filename).stem  # env.py -> env
+                root_file_imports.append(f"import {module_name}")
+
+            root_file_imports.append("")  # Blank line
+
+        return root_file_imports
+
     def _create_directory_structure(self) -> None:
         """Create the output directory structure"""
         # Create main directories
@@ -645,6 +661,137 @@ class CodeGenerator:
             "",
         ]
 
+    def _generate_readiness_section(self, project_path: Path) -> list[str]:
+        """Generate code section for readiness.py execution during server runtime."""
+        readiness_path = project_path / "readiness.py"
+
+        if not readiness_path.exists():
+            # Only generate default readiness if health checks are explicitly enabled
+            if not self.settings.health_check_enabled:
+                return []
+            return [
+                "# Default readiness check - no custom readiness.py found",
+                "@mcp.custom_route('/ready', methods=[\"GET\"])",
+                "async def readiness_check(request: Request) -> JSONResponse:",
+                '    """Readiness check endpoint for Kubernetes and load balancers."""',
+                '    return JSONResponse({"status": "pass"}, status_code=200)',
+                "",
+            ]
+
+        return [
+            "# Custom readiness check from readiness.py",
+            "from readiness import check as readiness_check_func",
+            "@mcp.custom_route('/ready', methods=[\"GET\"])",
+            "async def readiness_check(request: Request):",
+            '    """Readiness check endpoint for Kubernetes and load balancers."""',
+            "    result = readiness_check_func()",
+            "    if isinstance(result, dict):",
+            "        return JSONResponse(result)",
+            "    return result",
+            "",
+        ]
+
+    def _generate_health_section(self, project_path: Path) -> list[str]:
+        """Generate code section for health.py execution during server runtime."""
+        health_path = project_path / "health.py"
+
+        if not health_path.exists():
+            # Check if legacy health configuration is used
+            if self.settings.health_check_enabled:
+                return [
+                    "# Legacy health check configuration (deprecated)",
+                    "@mcp.custom_route('" + self.settings.health_check_path + '\', methods=["GET"])',
+                    "async def health_check(request: Request) -> PlainTextResponse:",
+                    '    """Health check endpoint for Kubernetes and load balancers."""',
+                    f'    return PlainTextResponse("{self.settings.health_check_response}")',
+                    "",
+                ]
+            else:
+                # If health checks are disabled, return empty (no default health check)
+                return []
+
+        return [
+            "# Custom health check from health.py",
+            "from health import check as health_check_func",
+            "@mcp.custom_route('/health', methods=[\"GET\"])",
+            "async def health_check(request: Request):",
+            '    """Health check endpoint for Kubernetes and load balancers."""',
+            "    result = health_check_func()",
+            "    if isinstance(result, dict):",
+            "        return JSONResponse(result)",
+            "    return result",
+            "",
+        ]
+
+    def _generate_check_function_helper(self) -> list[str]:
+        """Generate helper function to call custom check functions."""
+        return [
+            "# Helper function to call custom check functions",
+            "async def _call_check_function(check_type: str) -> JSONResponse:",
+            '    """Call custom check function and handle errors gracefully."""',
+            "    import importlib.util",
+            "    import traceback",
+            "    from pathlib import Path",
+            "    from datetime import datetime",
+            "    ",
+            "    try:",
+            "        # Load the custom check module",
+            "        module_path = Path(__file__).parent / f'{check_type}.py'",
+            "        if not module_path.exists():",
+            '            return JSONResponse({"status": "pass"}, status_code=200)',
+            "        ",
+            "        spec = importlib.util.spec_from_file_location(f'{check_type}_check', module_path)",
+            "        if spec and spec.loader:",
+            "            module = importlib.util.module_from_spec(spec)",
+            "            spec.loader.exec_module(module)",
+            "            ",
+            "            # Call the check function if it exists",
+            "            if hasattr(module, 'check'):",
+            "                result = module.check()",
+            "                ",
+            "                # Handle different return types",
+            "                if isinstance(result, dict):",
+            "                    # User returned structured response",
+            "                    status_code = result.get('status_code', 200)",
+            "                    response_data = {k: v for k, v in result.items() if k != 'status_code'}",
+            "                elif isinstance(result, bool):",
+            "                    # User returned simple boolean",
+            "                    status_code = 200 if result else 503",
+            "                    response_data = {",
+            '                        "status": "pass" if result else "fail",',
+            '                        "timestamp": datetime.utcnow().isoformat()',
+            "                    }",
+            "                elif result is None:",
+            "                    # User returned nothing - assume success",
+            "                    status_code = 200",
+            '                    response_data = {"status": "pass"}',
+            "                else:",
+            "                    # User returned something else - treat as success message",
+            "                    status_code = 200",
+            "                    response_data = {",
+            '                        "status": "pass",',
+            '                        "message": str(result)',
+            "                    }",
+            "                ",
+            "                return JSONResponse(response_data, status_code=status_code)",
+            "            else:",
+            "                return JSONResponse(",
+            '                    {"status": "fail", "error": f"No check() function found in {check_type}.py"},',
+            "                    status_code=503",
+            "                )",
+            "    ",
+            "    except Exception as e:",
+            "        # Log error and return failure response",
+            "        import sys",
+            '        print(f"Error calling {check_type} check function: {e}", file=sys.stderr)',
+            "        print(traceback.format_exc(), file=sys.stderr)",
+            "        return JSONResponse({",
+            '            "status": "fail",',
+            '            "error": f"Error calling {check_type} check function: {str(e)}"',
+            "        }, status_code=503)",
+            "",
+        ]
+
     def _generate_server(self) -> None:
         """Generate the main server entry point."""
         server_file = self.output_dir / "server.py"
@@ -679,6 +826,11 @@ class CodeGenerator:
             "",
         ]
 
+        # Add imports for root files
+        root_file_imports = self._generate_root_file_imports()
+        if root_file_imports:
+            imports.extend(root_file_imports)
+
         # Add auth imports if auth is configured
         if auth_components.get("has_auth"):
             imports.extend(auth_components["imports"])
@@ -700,14 +852,31 @@ class CodeGenerator:
             imports.extend(generate_metrics_instrumentation())
             imports.extend(generate_session_tracking())
 
-        # Add health check imports if enabled
-        if self.settings.health_check_enabled:
-            imports.extend(
-                [
-                    "from starlette.requests import Request",
-                    "from starlette.responses import PlainTextResponse",
-                ]
-            )
+        # Add health check imports only when we generate default endpoints
+        readiness_exists = (self.project_path / "readiness.py").exists()
+        health_exists = (self.project_path / "health.py").exists()
+
+        # Only import starlette when we generate default endpoints (not when custom files exist)
+        will_generate_default_readiness = not readiness_exists and self.settings.health_check_enabled
+        will_generate_default_health = not health_exists and self.settings.health_check_enabled
+
+        if will_generate_default_readiness or will_generate_default_health:
+            imports.append("from starlette.requests import Request")
+
+            # Determine response types needed for default endpoints
+            response_types = []
+            if will_generate_default_readiness:
+                response_types.append("JSONResponse")
+            if will_generate_default_health:
+                response_types.append("PlainTextResponse")
+
+            if response_types:
+                imports.append(f"from starlette.responses import {', '.join(response_types)}")
+
+        # Import Request and JSONResponse for custom check routes (they need both)
+        elif readiness_exists or health_exists:
+            imports.append("from starlette.requests import Request")
+            imports.append("from starlette.responses import JSONResponse")
 
         # Get transport-specific configuration
         transport_config = self._get_transport_config(self.settings.transport)
@@ -1199,22 +1368,17 @@ class CodeGenerator:
 
             metrics_route_code = generate_metrics_route(self.settings.metrics_path)
 
-        # Add health check route if enabled
-        health_check_code = []
-        if self.settings.health_check_enabled:
-            health_check_code = [
-                "# Add health check route",
-                "@mcp.custom_route('" + self.settings.health_check_path + '\', methods=["GET"])',
-                "async def health_check(request: Request) -> PlainTextResponse:",
-                '    """Health check endpoint for Kubernetes and load balancers."""',
-                (f'    return PlainTextResponse("{self.settings.health_check_response}")'),
-                "",
-            ]
+        # Generate readiness and health check sections
+        readiness_section = self._generate_readiness_section(self.project_path)
+        health_section = self._generate_health_section(self.project_path)
+
+        # No longer need the check helper function since we use direct imports
+        check_helper_section = []
 
         # Combine all sections
         # Order: imports, env_section, startup_section, auth_setup, server_code (mcp init),
         # early_telemetry_init, early_metrics_init, component_registrations,
-        # metrics_route_code, health_check_code, main_code (run block)
+        # metrics_route_code, check_helper_section, readiness_section, health_section, main_code (run block)
         code = "\n".join(
             imports
             + env_section
@@ -1225,7 +1389,9 @@ class CodeGenerator:
             + early_metrics_init
             + component_registrations
             + metrics_route_code
-            + health_check_code
+            + check_helper_section
+            + readiness_section
+            + health_section
             + main_code
         )
 
@@ -1256,21 +1422,13 @@ def build_project(
         build_env: Build environment ('dev' or 'prod')
         copy_env: Whether to copy environment variables to the built app
     """
-    # Load Golf credentials from .env for build operations (platform registration, etc.)
-    # This happens regardless of copy_env setting to ensure build process works
+    # Load environment variables from .env for build operations
     from dotenv import load_dotenv
 
     project_env_file = project_path / ".env"
     if project_env_file.exists():
-        # Load GOLF_* variables for build process
         load_dotenv(project_env_file, override=False)
 
-        # Only log if we actually found the specific Golf platform credentials
-        has_api_key = "GOLF_API_KEY" in os.environ
-        has_server_id = "GOLF_SERVER_ID" in os.environ
-        if has_api_key and has_server_id:
-            console.print("[dim]Loaded Golf credentials for build operations[/dim]")
-
     # Execute auth.py if it exists (for authentication configuration)
     # Also support legacy pre_build.py for backward compatibility
     auth_path = project_path / "auth.py"
@@ -1427,32 +1585,27 @@ def build_project(
         shutil.copy2(startup_path, dest_path)
         console.print(get_status_text("success", "Startup script copied to build directory"))
 
-    # Platform registration (only for prod builds)
-    if build_env == "prod":
-        console.print()
-        status_msg = f"[{GOLF_BLUE}]{STATUS_ICONS['platform']} Registering with Golf platform and updating resources...[/{GOLF_BLUE}]"
-        with console.status(status_msg):
-            import asyncio
+    # Copy optional check files to build directory
+    readiness_path = project_path / "readiness.py"
+    if readiness_path.exists():
+        shutil.copy2(readiness_path, output_dir)
+        console.print(get_status_text("success", "Readiness script copied to build directory"))
 
-            try:
-                from golf.core.platform import register_project_with_platform
+    health_path = project_path / "health.py"
+    if health_path.exists():
+        shutil.copy2(health_path, output_dir)
+        console.print(get_status_text("success", "Health script copied to build directory"))
 
-                success = asyncio.run(
-                    register_project_with_platform(
-                        project_path=project_path,
-                        settings=settings,
-                        components=generator.components,
-                    )
-                )
+    # Copy any additional Python files from project root
+    discovered_root_files = discover_root_files(project_path)
 
-                if success:
-                    console.print(get_status_text("success", "Platform registration completed"))
-                # If success is False, the platform module already printed appropriate warnings
-            except ImportError:
-                console.print(get_status_text("warning", "Platform registration module not available"))
-            except Exception as e:
-                console.print(get_status_text("warning", f"Platform registration failed: {e}"))
-                console.print("[dim]Tip: Ensure GOLF_API_KEY and GOLF_SERVER_ID are available in your .env file[/dim]")
+    for filename, file_path in discovered_root_files.items():
+        dest_path = output_dir / filename
+        try:
+            shutil.copy2(file_path, dest_path)
+            console.print(get_status_text("success", f"Root file {filename} copied to build directory"))
+        except (OSError, shutil.Error) as e:
+            console.print(f"[red]Error copying {filename}: {e}[/red]")
 
     # Create a simple README
     readme_content = f"""# {settings.name}
@@ -1483,7 +1636,7 @@ This is a standalone FastMCP server generated by GolfMCP.
 
 # Legacy ProviderConfig removed in Golf 0.2.x - use modern auth configurations
 # Legacy OAuth imports removed in Golf 0.2.x - use FastMCP 2.11+ auth providers
-from golf.auth.helpers import get_provider_token, extract_token_from_header, get_api_key, set_api_key
+from golf.auth.helpers import extract_token_from_header, get_api_key, set_api_key
 from golf.auth.api_key import configure_api_key, get_api_key_config
 from golf.auth.factory import create_auth_provider
 from golf.auth.providers import RemoteAuthConfig, JWTAuthConfig, StaticTokenConfig, OAuthServerConfig
@@ -1553,6 +1706,86 @@ from golf.auth.providers import RemoteAuthConfig, JWTAuthConfig, StaticTokenConf
                 )
 
 
+def discover_root_files(project_path: Path) -> dict[str, Path]:
+    """Automatically discover all Python files in the project root directory.
+
+    This function finds all .py files in the project root, excluding:
+    - Special Golf files (startup.py, health.py, readiness.py, auth.py, server.py)
+    - Component directories (tools/, resources/, prompts/)
+    - Hidden files and common exclusions (__pycache__, .git, etc.)
+
+    Args:
+        project_path: Path to the project root directory
+
+    Returns:
+        Dictionary mapping filenames to their full paths
+    """
+    import ast
+
+    discovered_files = {}
+
+    # Files that are handled specially by Golf and should not be auto-copied
+    reserved_files = {
+        "startup.py",
+        "health.py",
+        "readiness.py",
+        "auth.py",
+        "server.py",
+        "pre_build.py",  # Legacy auth file
+        "golf.json",
+        "golf.toml",  # Config files
+        "__init__.py",  # Package files
+    }
+
+    # Find all .py files in the project root (not in subdirectories)
+    try:
+        for file_path in project_path.iterdir():
+            if not file_path.is_file():
+                continue
+
+            filename = file_path.name
+
+            # Skip non-Python files
+            if not filename.endswith(".py"):
+                continue
+
+            # Skip reserved/special files
+            if filename in reserved_files:
+                continue
+
+            # Skip hidden files and temporary files
+            if filename.startswith(".") or filename.startswith("_") or filename.endswith("~"):
+                continue
+
+            # Validate it's a readable Python file
+            try:
+                with open(file_path, encoding="utf-8") as f:
+                    # Read first 200 chars to validate it's a proper Python file
+                    content = f.read(200)
+
+                # Basic Python syntax validation
+                try:
+                    ast.parse(content + "\n# truncated for validation")
+                except SyntaxError:
+                    # Still include files with syntax errors, but warn
+                    console.print(f"[yellow]Warning: {filename} has syntax issues but will be included[/yellow]")
+
+            except (OSError, UnicodeDecodeError) as e:
+                console.print(f"[yellow]Warning: Cannot read {filename}, skipping: {e}[/yellow]")
+                continue
+
+            discovered_files[filename] = file_path
+
+    except OSError as e:
+        console.print(f"[yellow]Warning: Error scanning project directory: {e}[/yellow]")
+
+    if discovered_files:
+        file_list = ", ".join(sorted(discovered_files.keys()))
+        console.print(f"[dim]Found root Python files: {file_list}[/dim]")
+
+    return discovered_files
+
+
 # Legacy function removed - replaced by parse_shared_files in parser module
 
 
